@@ -199,6 +199,38 @@ G_BEGIN_DECLS
  **/
 #define E_CAL_STATIC_CAPABILITY_TASK_HANDLE_RECUR	"task-handle-recur"
 
+/**
+ * E_CAL_STATIC_CAPABILITY_SIMPLE_MEMO:
+ *
+ * When the capability is set, the backend handles only simple memos,
+ * which means it stores only memo description. The summary can be changed
+ * by the backend, if needed.
+ *
+ * Since: 3.38
+ **/
+#define E_CAL_STATIC_CAPABILITY_SIMPLE_MEMO		"simple-memo"
+
+/**
+ * E_CAL_STATIC_CAPABILITY_SIMPLE_MEMO_WITH_SUMMARY:
+ *
+ * Similar to the %E_CAL_STATIC_CAPABILITY_SIMPLE_MEMO, except the backend stores
+ * the description and the summary separately.
+ *
+ * Since: 3.42
+ **/
+
+#define E_CAL_STATIC_CAPABILITY_SIMPLE_MEMO_WITH_SUMMARY "simple-memo-with-summary"
+
+/**
+ * E_CAL_STATIC_CAPABILITY_TASK_ESTIMATED_DURATION:
+ *
+ * Set, when the backend supports ESTIMATED-DURATION property for tasks.
+ *
+ * Since: 3.44
+ **/
+
+#define E_CAL_STATIC_CAPABILITY_TASK_ESTIMATED_DURATION "task-estimated-duration"
+
 struct _ECalClient;
 
 ICalComponent *	e_cal_util_new_top_level	(void);
@@ -208,6 +240,13 @@ ICalTimezone *	e_cal_util_copy_timezone	(const ICalTimezone *zone);
 ICalComponent *	e_cal_util_parse_ics_string	(const gchar *string);
 ICalComponent *	e_cal_util_parse_ics_file	(const gchar *filename);
 
+gboolean	e_cal_util_has_alarms_in_range	(ECalComponent *comp,
+						 time_t start,
+						 time_t end,
+						 ECalComponentAlarmAction *omit,
+						 ECalRecurResolveTimezoneCb resolve_tzid,
+						 gpointer user_data,
+						 ICalTimezone *default_timezone);
 ECalComponentAlarms *
 		e_cal_util_generate_alarms_for_comp
 						(ECalComponent *comp,
@@ -226,7 +265,18 @@ gint		e_cal_util_generate_alarms_for_list
 						 ECalRecurResolveTimezoneCb resolve_tzid,
 						 gpointer user_data,
 						 ICalTimezone *default_timezone);
-
+ECalComponentAlarms *
+		e_cal_util_generate_alarms_for_uid_sync
+						(struct _ECalClient *client,
+						 const gchar *uid,
+						 time_t start,
+						 time_t end,
+						 ECalComponentAlarmAction *omit,
+						 ECalRecurResolveTimezoneCb resolve_tzid,
+						 gpointer user_data,
+						 ICalTimezone *default_timezone,
+						 GCancellable *cancellable,
+						 GError **error);
 const gchar *	e_cal_util_priority_to_string	(gint priority);
 gint		e_cal_util_priority_from_string	(const gchar *string);
 
@@ -257,12 +307,29 @@ gchar *		e_cal_util_component_get_recurid_as_string
 						(ICalComponent *icalcomp);
 ICalComponent *	e_cal_util_construct_instance	(ICalComponent *icalcomp,
 						 const ICalTime *rid);
+/* #ifndef EDS_DISABLE_DEPRECATED */ /* Fully deprecate it for 3.40 */
 void		e_cal_util_remove_instances	(ICalComponent *icalcomp,
 						 const ICalTime *rid,
 						 ECalObjModType mod);
 ICalComponent *	e_cal_util_split_at_instance	(ICalComponent *icalcomp,
 						 const ICalTime *rid,
 						 const ICalTime *master_dtstart);
+/* #endif / * EDS_DISABLE_DEPRECATED */
+void		e_cal_util_normalize_rrule_until_value
+						(ICalComponent *icalcomp,
+						 ICalTime *ttuntil,
+						 ECalRecurResolveTimezoneCb tz_cb,
+						 gpointer tz_cb_data);
+void		e_cal_util_remove_instances_ex	(ICalComponent *icalcomp,
+						 const ICalTime *rid,
+						 ECalObjModType mod,
+						 ECalRecurResolveTimezoneCb tz_cb,
+						 gpointer tz_cb_data);
+ICalComponent *	e_cal_util_split_at_instance_ex	(ICalComponent *icalcomp,
+						 const ICalTime *rid,
+						 const ICalTime *master_dtstart,
+						 ECalRecurResolveTimezoneCb tz_cb,
+						 gpointer tz_cb_data);
 gboolean	e_cal_util_is_first_instance	(ECalComponent *comp,
 						 const ICalTime *rid,
 						 ECalRecurResolveTimezoneCb tz_cb,
@@ -315,6 +382,50 @@ EConflictResolution
 						(guint32 flags); /* bit-or of ECalOperationFlags */
 guint32		e_cal_util_conflict_resolution_to_operation_flags /* bit-or of ECalOperationFlags */
 						(EConflictResolution conflict_resolution);
+gboolean	e_cal_util_inline_local_attachments_sync
+						(ICalComponent *component,
+						 GCancellable *cancellable,
+						 GError **error);
+gboolean	e_cal_util_set_alarm_acknowledged
+						(ECalComponent *component,
+						 const gchar *auid,
+						 gint64 when); /* as time_t in UTC */
+void		e_cal_util_clamp_vtimezone	(ICalComponent *vtimezone,
+						 const ICalTime *from,
+						 const ICalTime *to);
+void		e_cal_util_clamp_vtimezone_by_component
+						(ICalComponent *vtimezone,
+						 ICalComponent *component);
+ICalProperty *	e_cal_util_component_find_property_for_locale
+						(ICalComponent *icalcomp,
+						 ICalPropertyKind prop_kind,
+						 const gchar *locale);
+/**
+ * ECalUtilForeachCategoryFunc:
+ * @comp: an #ICalComponent
+ * @inout_category: (inout): the category name
+ * @user_data: user data for the callback
+ *
+ * Function called for each non-empty category from e_cal_util_foreach_category().
+ * The @func can assume owenrship of the @inout_category content, in which case
+ * it should also set its content to %NULL, to avoid free of it. The string itself,
+ * if taken, should be freed with g_free(), when no longer needed.
+ *
+ * Returns: %TRUE to continue, %FALSE to stop
+ *
+ * Since: 3.48
+ **/
+typedef gboolean (* ECalUtilForeachCategoryFunc)(ICalComponent *comp,
+						 gchar **inout_category,
+						 gpointer user_data);
+
+void		e_cal_util_foreach_category	(ICalComponent *comp,
+						 ECalUtilForeachCategoryFunc func,
+						 gpointer user_data);
+void		e_cal_util_diff_categories	(ICalComponent *old_comp,
+						 ICalComponent *new_comp,
+						 GHashTable **out_added, /* const gchar *category ~> 1 */
+						 GHashTable **out_removed); /* const gchar *category ~> 1 */
 
 G_END_DECLS
 
